Module: LesliShield
- Defined in:
- lib/lesli_shield/engine.rb,
lib/lesli_shield.rb,
lib/lesli_shield/router.rb,
lib/lesli_shield/version.rb,
app/models/lesli_shield/user.rb,
app/models/lesli_shield/invite.rb,
app/models/lesli_shield/account.rb,
app/models/lesli_shield/setting.rb,
app/services/lesli_shield/tokens.rb,
app/models/lesli_shield/dashboard.rb,
app/models/lesli_shield/user/role.rb,
app/models/lesli_shield/role/action.rb,
app/models/lesli_shield/user/session.rb,
app/helpers/lesli_shield/users_helper.rb,
app/jobs/lesli_shield/application_job.rb,
app/mailers/lesli_shield/devise_mailer.rb,
app/models/lesli_shield/role/privilege.rb,
app/helpers/lesli_shield/invites_helper.rb,
app/helpers/lesli_shield/sessions_helper.rb,
app/helpers/lesli_shield/settings_helper.rb,
app/services/lesli_shield/invite_service.rb,
app/helpers/lesli_shield/dashboards_helper.rb,
app/helpers/lesli_shield/user/roles_helper.rb,
app/models/lesli_shield/application_record.rb,
app/helpers/lesli_shield/application_helper.rb,
app/mailers/lesli_shield/application_mailer.rb,
app/controllers/lesli_shield/roles_controller.rb,
app/controllers/lesli_shield/users_controller.rb,
app/services/lesli_shield/role_action_service.rb,
app/models/concerns/lesli_shield/user_security.rb,
app/services/lesli_shield/user_session_service.rb,
app/controllers/lesli_shield/invites_controller.rb,
app/controllers/lesli_shield/sessions_controller.rb,
app/controllers/lesli_shield/settings_controller.rb,
app/services/lesli_shield/role_privilege_service.rb,
app/services/lesli_shield/user_validator_service.rb,
app/controllers/lesli_shield/dashboards_controller.rb,
app/controllers/lesli_shield/user/roles_controller.rb,
app/controllers/lesli_shield/application_controller.rb,
app/interfaces/lesli_shield/authorization_interface.rb,
app/services/lesli_shield/user_registration_service.rb,
app/controllers/lesli_shield/role/actions_controller.rb,
app/interfaces/lesli_shield/authentication_interface.rb
Overview
Lesli
Copyright © 2026, Lesli Technologies, S. A.
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see www.gnu.org/licenses/.
Lesli · Ruby on Rails SaaS Development Framework.
Made with ♥ by LesliTech Building a better future, one line of code at a time.
// · ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ // ·
Defined Under Namespace
Modules: ApplicationHelper, AuthenticationInterface, AuthorizationInterface, DashboardsHelper, InvitesHelper, Router, SessionsHelper, SettingsHelper, UserSecurity, UsersHelper Classes: Account, ApplicationController, ApplicationJob, ApplicationMailer, ApplicationRecord, Dashboard, DashboardsController, DeviseMailer, Engine, Invite, InviteService, InvitesController, RoleActionService, RolePrivilegeService, RolesController, SessionsController, Setting, SettingsController, Tokens, User, UserRegistrationService, UserSessionService, UserValidatorService, UsersController
Constant Summary collapse
- VERSION =
"1.1.1"- BUILD =
"1777174912"